| Home | Libraries | People | FAQ | More

## Getting Started

This section explains how to setup a system to use this library.

### Compilers and Platforms

The authors originally developed and tested this library on:

1. GNU Compiler Collection (GCC) C++ 4.5.3 (with and without C++11 features enabled `-std=c++0x`) on Cygwin.
2. Miscrosoft Visual C++ (MSVC) 8.0 on Windows 7.

See the library regressions test results for detailed information on supported compilers and platforms. Check the library regression test `Jamfile.v2` for any special configuration that might be required for a specific compiler.

### Installation

This library is composed of header files only. Therefore there is no pre-compiled object file which needs to be installed. Programmers can simply instruct the compiler where to find the library header files (`-I` option on GCC, `/I` option on MSVC, etc) and compile code using the library.

The maximum number of functions to overload is given by the `BOOST_FUNCTIONAL_OVERLOADED_FUNCTION_CONFIG_OVERLOAD_MAX` configuration macro. The maximum number of function parameters for each of the specified function type is given by the `BOOST_FUNCTIONAL_OVERLOADED_FUNCTION_CONFIG_ARITY_MAX` configuration macro. All configuration macros have appropriate default values when they are left undefined.